@@ -1,3 +1,4 @@
+from .update_dockerfile import UpdateDockerfileAction
 from .download_resources import DownloadResourcesAction
 from .update_image_tag import UpdateImageTagAction
 from .update_yaml import UpdateYamlAction
@@ -12,5 +13,7 @@ def create_action(name, source_version, latest_version, config) -> IAction:
         return DownloadResourcesAction(name, source_version, latest_version, config)
     elif source_type == "update-yaml":
         return UpdateYamlAction(name, source_version, latest_version, config)
+    elif source_type == "update-dockerfile":
+        return UpdateDockerfileAction(name, source_version, latest_version, config)
     else:
         raise Exception(f"Unknown Source Type: {source_type}")
